@@ -1,4 +1,4 @@
-plot.rgl.coin <- function(x, col='black', heads=x[[1]],
+rgl.coin <- function(x, col='black', heads=x[[1]],
                           tails=x[[2]], ... ) {
     if(!require(rgl)) stop("This function depends on the 'rgl' library which is not available")
 
